@@ -5,7 +5,6 @@ __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
 
-import numpy as np
 from scipy import constants
 from scipy.optimize import brentq
 from .particles import Atom, MoleculeMultiT, MoleculeQuasi, MoleculeOneT, Molecule
@@ -66,7 +65,7 @@ def Gamma_vt(T: float, T1: float, molecule: MoleculeMultiT, delta: int) -> float
 
 
 def Gamma_vv_sts(T: float, molecule1: Molecule, molecule2: Molecule, i: int, k: int, i_delta: int,
-                 k_delta: int, ni_before1: float, ni_before2: float, ni_afer1: float, ni_afer2: float) -> float:
+                 k_delta: int, ni_before1: float, ni_before2: float, ni_after1: float, ni_after2: float) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
     **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the state-to-state approximation
 
@@ -103,7 +102,7 @@ def Gamma_vv_sts(T: float, molecule1: Molecule, molecule2: Molecule, i: int, k:
     """
     return raw_Gamma_vv_sts(T, molecule1.vibr[i], molecule2.vibr[k],
                             molecule1.vibr[i + i_delta], molecule2.vibr[k + k_delta],
-                            ni_before1, ni_before2, ni_afer1, ni_afer2)
+                            ni_before1, ni_before2, ni_after1, ni_after2)
 
 
 def Gamma_vv(T: float, T1_1: float, T1_2: float, molecule1: MoleculeMultiT, molecule2: MoleculeMultiT, i_delta: int,
@@ -156,14 +155,6 @@ def Gamma_22_sts(T: float, molecule1: Molecule, molecule2: Molecule, molecule_ne
         the molecule M3
     molecule_new2 : Molecule
         the molecule M4
-    i : int
-        the vibrational level of molecule M1
-    k : int
-        the vibrational level of molecule M2
-    i_new : int
-        the vibrational level of molecule M3
-    k_new : int
-        the vibrational level of molecule M4
     n_molecule1 : float
         the numeric density of molecules of species M1 at the vibrationa level i
     n_molecule2 : float
@@ -172,6 +163,14 @@ def Gamma_22_sts(T: float, molecule1: Molecule, molecule2: Molecule, molecule_ne
         the numeric density of molecules of species M3 at the vibrationa level i_new
     n_molecule_new2 : float
         the numeric density of molecules of species M4 at the vibrationa level k_new
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_new : int
+        the vibrational level of molecule M3
+    k_new : int
+        the vibrational level of molecule M4
 
     Returns
     -------
@@ -370,7 +369,7 @@ def find_natom_diss_eq(T: float, molecule: MoleculeOneT, atom: Atom, n: float, r
     return raw_find_natom_diss_eq(T, molecule.Z_int(T), molecule.mass, atom.mass, molecule.diss, n, relative)
 
 
-def raw_Gamma_vt_sts(T: float, ve_before: float, ve_after: float, ni_before: float, ni_afer: float) -> float:
+def raw_Gamma_vt_sts(T: float, ve_before: float, ve_after: float, ni_before: float, ni_after: float) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
     **M(i) + P -> M(i+delta) + P** in the state-to-state approximation, *raw* version
 
@@ -393,7 +392,7 @@ def raw_Gamma_vt_sts(T: float, ve_before: float, ve_after: float, ni_before: flo
         The generalized thermodynamic force for a VT transition
 
     """
-    return 1.0 - ni_afer * exp((ve_after - ve_before) / (constants.k * T)) / ni_before
+    return 1.0 - ni_after * exp((ve_after - ve_before) / (constants.k * T)) / ni_before
 
 
 def raw_Gamma_vt(T: float, T1: float, vibr_one: float, delta: int) -> float:
@@ -421,7 +420,7 @@ def raw_Gamma_vt(T: float, T1: float, vibr_one: float, delta: int) -> float:
 
 
 def raw_Gamma_vv_sts(T: float, ve_before1: float, ve_before2: float, ve_after1: float, ve_after2: float,
-                     ni_before1: float, ni_before2: float, ni_afer1: float, ni_afer2: float) -> float:
+                     ni_before1: float, ni_before2: float, ni_after1: float, ni_after2: float) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
     **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the state-to-state approximation, *raw* version
 
@@ -452,7 +451,7 @@ def raw_Gamma_vv_sts(T: float, ve_before1: float, ve_before2: float, ve_after1:
         The generalized thermodynamic force for a VV transition
 
     """
-    return 1.0 - ni_afer1 * ni_afer2 * exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / (constants.k * T))\
+    return 1.0 - ni_after1 * ni_after2 * exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / (constants.k * T))\
                  / (ni_before1 * ni_before2)
 
 
@@ -552,8 +551,8 @@ def raw_Gamma_22_sts(T: float, ve_before1: float, ve_before2: float, ve_after1:
     add = Z_rot1 * Z_rot2 / (Z_rot_new1 * Z_rot_new2)
     add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
-    add *= np.exp((form_new1 + form_new2 - form1 - form2) / kT)
-    add *= np.exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / kT)
+    add *= exp((form_new1 + form_new2 - form1 - form2) / kT)
+    add *= exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / kT)
 
     return 1.0 - add
 
@@ -648,9 +647,9 @@ def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: fl
     add = Z_int1 * Z_int2 / (Z_int_new1 * Z_int_new2)
     add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
-    add *= np.exp((form_new1 + form_new2 - form1 - form2 + vibr_zero_new1 + vibr_zero_new2
+    add *= exp((form_new1 + form_new2 - form1 - form2 + vibr_zero_new1 + vibr_zero_new2
                   - vibr_zero1 - vibr_zero2) / kT)
-    add *= np.exp(vibr_one1 * i * (1.0 / (constants.k * T1_1) - 1.0 / kT)
+    add *= exp(vibr_one1 * i * (1.0 / (constants.k * T1_1) - 1.0 / kT)
                   + vibr_one2 * k * (1.0 / (constants.k * T1_2) - 1.0 / kT)
                   - vibr_one_new1 * i_new * (1.0 / (constants.k * T1_new1) - 1.0 / kT)
                   - vibr_one_new2 * k_new * (1.0 / (constants.k * T1_new2) - 1.0 / kT))
@@ -712,7 +711,7 @@ def raw_Gamma_22_oneT(T: float, Z_int1: float, Z_int2: float, Z_int_new1: float,
     add = Z_int1 * Z_int2 / (Z_int_new1 * Z_int_new2)
     add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
-    add *= np.exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT)
+    add *= exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT)
     return 1.0 - add
 
 
@@ -726,6 +725,8 @@ def raw_Gamma_diss_sts(T: float, molecule_vibr: float,
     ----------
     T : float
         the temperature of the mixture
+    molecule_vibr : float
+        the vibrational energy of the level from which the molecule dissociates
     Z_rot : float
         the value of the rotational partition function of the molecule which dissociates
     mass_molecule : float
