@@ -165,6 +165,8 @@ class Molecule(Particle):
         the 0th vibrational level in the ``vibr`` array is equal to 0)
     crot : float
         The specific heat capacity of rotational degrees of freedom
+    infcoll : float
+        The Parker's limiting value for the molecular species
 
     Notes
     -----
@@ -211,6 +213,7 @@ class Molecule(Particle):
         self.vibr = np.zeros(self.num_vibr + 1)
         self.vibr_zero = 0
         self.crot = constants.k / self.mass
+        self.infcoll = raw_d[12]
 
         self._current_T = 1.0
         self._current_Z_rot = 0.0
